@@ -23,15 +23,17 @@ grouped_matrix_arules <- function(rules, measure, shading, control=NULL, ...){
   ## shading controls color
   
   control <- .get_parameters(control, list(
-    main = paste("Grouped matrix for", length(rules), "rules"),
+    main = paste("Grouped Matrix for", length(rules), "Rules"),
     k = 20,
+    rhs_max = 10,
+    lhs_items = 2,
     aggr.fun=median, 
     ## fix lift so serveral plots are comparable (NA: take max)
     col = default_colors(100),
     reverse = TRUE, 
     xlab = NULL, 
     ylab = NULL, 
-    legend = paste("size:", measure, "\ncolor:", shading),
+    legend = paste("Size:", measure, "\nColor:", shading),
     spacing = -1, 
     panel.function = panel.circles, 
     gp_main   = gpar(cex=1.2, fontface="bold"),
@@ -61,7 +63,8 @@ grouped_matrix_arules <- function(rules, measure, shading, control=NULL, ...){
     row.names = c("inspect","zoom in", "zoom out", "end"),
     active = rep(FALSE, 4),
     x = c(0.3, 0.5, 0.7, 0.9),
-    y = I(rep(unit(-3, "lines"), 4)),
+    y = I(rep(unit(0, "lines"), 4)),
+    #y = I(rep(unit(-3, "lines"), 4)),
     w = I(rep(unit(3.5, "lines"), 4)),
     h = I(rep(unit(1, "lines"), 4))
   )
@@ -199,7 +202,7 @@ grouped_matrix_int <- function(rules, measure, shading, control) {
   mAggr <- .aggr(rulesAsMatrix(rules, measure[1]), km, aggr.fun)
   
   ret <- list(rules=rules, measure=measure, shading=shading, 
-    cl=cl, km= km, max.shading=max.shading, 
+    cl=cl, km= km, lhs_items = control$lhs_items, max.shading=max.shading, 
     aggr.fun=aggr.fun, 
     order=order, k=k, sAggr=sAggr, mAggr=mAggr)
   class(ret) <- "grouped_matrix"
@@ -222,20 +225,28 @@ plot.grouped_matrix <- function(x, ...) {
   ln <- x$sAggr
   
   ## get most important item in the lhs
-  f <- lapply(split(x$rules, x$cl), FUN = function(r) itemFrequency(lhs(r)))
+  f <- lapply(split(x$rules, x$cl), FUN = function(r) itemFrequency(lhs(r), 
+    type = "absolute"))
+  ## divide by sum to find most important item...
+  f <- lapply(f, "/", itemFrequency(lhs(x$rules), type = "absolute")+1L)
+ 
   most_imp_item <- lapply(f, FUN = 
       function(x) {
         items <- sum(x>0)
         if(items==0) { "" }
-        else if(items>1){
-          paste(names(which.max(x)), ", +",sum(x>0)-1, " items", sep="")
+        else if(control$lhs_items<1){ 
+          paste(items, "items") 
+        } else if(items>control$lhs_items){
+          paste(paste(names(x[head(order(x, decreasing = TRUE), n = control$lhs_items)]), 
+            collapse = ", "), ", +", items-control$lhs_items, " items", sep="")
         }else{
-          names(which.max(x))   
+          paste(names(x[head(order(x, decreasing = TRUE), n = control$lhs_items)]), 
+            collapse = ", ")
         }
       })
  
   control$ylab <- paste(
-    paste('{',most_imp_item, '}', " - ", table(x$cl), " rules", sep=''))
+    paste(format(table(x$cl)), " rules: ", '{',most_imp_item, '}', sep=''))
       
   grouped_matrix_plot_int(
     x = map(sn, c(0.2,1)), 
@@ -257,7 +268,7 @@ inspect.grouped_matrix <- function(x, cluster, measure="lift") {
 grouped_matrix_plot_int <- function(x, y, order = NULL, options = NULL) {
   if (!is.matrix(x)) 
     stop("Argument 'x' must be a matrix.")
-  
+
   if (!is.null(options$xlab)) rownames(x) <- options$xlab
   if (!is.null(options$ylab)) colnames(x) <- options$ylab
   
@@ -266,6 +277,16 @@ grouped_matrix_plot_int <- function(x, y, order = NULL, options = NULL) {
     y <- permute(y, order)
   }
   
+  ### only show the top RHS
+  suppressed_rhs <- 0
+  if(!is.null(options$rhs_max) && 
+      options$rhs_max > 0 && 
+      nrow(x) > options$rhs_max) {
+    suppressed_rhs <- nrow(x) - options$rhs_max
+    x <- x[1:options$rhs_max, , drop=FALSE]
+    y <- y[1:options$rhs_max, , drop = FALSE]
+  }
+  
   if (options$reverse) {
     x <- t(x)
     y <- t(y)
@@ -293,18 +314,24 @@ grouped_matrix_plot_int <- function(x, y, order = NULL, options = NULL) {
   
   upViewport(1)
   
-  ## determine margins
+  # determine margins for labels
+  # Note: rownames are LHSs!
   #topSpace <- max(stringWidth(rownames(x)))
-  topSpace <- max(grobWidth(textGrob(rownames(x), gp=options$gp_labels)))
+  topSpace <- max(grobHeight(textGrob(rownames(x), rot = 90, 
+    gp=options$gp_labels)))
+  #, gp=options$gp_labels))
   #rightSpace <- max(stringWidth(colnames(x)))
-  rightSpace <- max(grobWidth(textGrob(colnames(x), gp=options$gp_labels)))
+  rightSpace <- max(grobWidth(textGrob(colnames(x), 
+    gp=options$gp_labels)))
   
-  pushViewport(viewport(x=unit(2,"lines"), y=unit(4,"lines"),
+  # have 2 lines to the left and 2 lines from bottom 
+  pushViewport(viewport(x=unit(2,"lines"), y=unit(2,"lines"), 
     just = c("left","bottom"),
-    width = unit(1, "npc")-rightSpace-unit(3+4,"lines"), 
-    height = unit(1, "npc")-topSpace-unit(4+3,"lines"),
+    width = unit(1, "npc")-(rightSpace+unit(3+4,"lines")), 
+    height = unit(1, "npc")-(topSpace+unit(4+4+3,"lines")),
     #xscale = c(1, nrow(x)), yscale = c(1, ncol(x)), 
-    xscale = c(.5, nrow(x)+.5), yscale = c(.5, ncol(x)+.5), 
+    #xscale = c(.5, nrow(x)+.5), yscale = c(.5, ncol(x)+.5), 
+    xscale = c(.5, nrow(x)+.5), yscale = c(0, ncol(x)+.5), 
     default.units = "native",
     #gp = options$gp_labels,
     name="grouped_matrix"))
@@ -345,18 +372,38 @@ grouped_matrix_plot_int <- function(x, y, order = NULL, options = NULL) {
     just = "left", 
     default.units = "native",
     gp = options$gp_labels)
+
+  if(suppressed_rhs > 0 && options$reverse) 
+    grid.text(
+      paste0("+ ", suppressed_rhs, " supressed"), 
+      x = xLabPos, y = 0, 
+      just = "left", 
+      default.units = "native",
+      gp = options$gp_labels)
   
+   
   ## add lhs, rhs
-  grid.text("LHS", 
-    x = unit(1, "native")-unit(1,"lines"), y = yLabPos, 
-    rot = 90, just = "left", 
-    default.units = "native", 
-    gp = options$gp_labs)
-  grid.text("RHS", x = xLabPos,  
-    y = unit(ncol(x), "native")+unit(1,"lines"), 
-    just = "left", 
-    default.units = "native", gp = options$gp_labs)
-  
+  if(options$reverse) {
+    grid.text("Items in LHS Group", 
+      x = unit(1, "native")-unit(1,"lines"), y = yLabPos, 
+      rot = 90, just = "left", 
+      default.units = "native", 
+      gp = options$gp_labs)
+    grid.text("RHS", x = xLabPos,  
+      y = unit(ncol(x), "native")+unit(1,"lines"), 
+      just = "left", 
+      default.units = "native", gp = options$gp_labs)
+  }else{
+    grid.text("RHS", 
+      x = unit(1, "native")-unit(1,"lines"), y = yLabPos, 
+      rot = 90, just = "left", 
+      default.units = "native", 
+      gp = options$gp_labs)
+    grid.text("Items in LHS Group", x = xLabPos,  
+      y = unit(ncol(x), "native")+unit(1,"lines"), 
+      just = "left", 
+      default.units = "native", gp = options$gp_labs)
+  }
   
   
   upViewport(1)
